@@ -7,7 +7,7 @@ package Sub::HandlesVia;
 use Exporter::Shiny qw( delegations );
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.001';
+our $VERSION   = '0.002';
 
 sub import {
 	my $me     = shift;
@@ -118,7 +118,7 @@ before, you should have a fairly good idea what this does.
 
 Why re-invent the wheel? Well, this is an implementation that should work
 okay with Moo, Moose, Mouse, and any other OO toolkit you throw at it.
-One ring to rule them all, so to speak. (Moose support is a TODO though!)
+One ring to rule them all, so to speak.
 
 Also, unlike L<MooX::HandlesVia>, it honours type constraints, plus it
 doesn't have the limitation that it can't mutate non-reference values.
@@ -509,7 +509,7 @@ encapsulation of course):
 
 And C<< $kitchen->find_healthiest_food >> does this:
 
-  C<< $kitchen->food->find_healthiest >>
+  $kitchen->food->find_healthiest
 
 Basically, because C<find_healthiest> isn't one of the methods offered
 by Sub::HandlesVia::HandlerList::Array, it assumes you want to call it
